@@ -27,8 +27,8 @@ import numpy
 from osgeo import gdal
 from osgeo import osr
 from osgeo import ogr
-from PyQt4.QtGui import QImage, QPainter, QPen
-from PyQt4.QtCore import QObject, SIGNAL
+from PyQt5.QtGui import QImage, QPainter, QPen
+from PyQt5.QtCore import QObject, pyqtSignal
 import threading
 if sys.version_info[0] < 3:
    import Queue as queue
@@ -313,19 +313,13 @@ class ViewerRasterLayer(ViewerLayer):
         self.image = None
 
         # connect the signals from the RAT and LUT back to the layermanager
-        layermanager.connect(self.lut, SIGNAL("newProgress(QString)"), 
-                                                    layermanager.newProgress)
-        layermanager.connect(self.lut, SIGNAL("endProgress()"), 
-                                                    layermanager.endProgress)
-        layermanager.connect(self.lut, SIGNAL("newPercent(int)"), 
-                                                    layermanager.newPercent)
+        self.lut.newProgress.connect(layermanager.newProgress)
+        self.lut.endProgress.connect(layermanager.endProgress)
+        self.lut.newPercent.connect(layermanager.newPercent)
 
-        layermanager.connect(self.attributes, SIGNAL("newProgress(QString)"), 
-                                                    layermanager.newProgress)
-        layermanager.connect(self.attributes, SIGNAL("endProgress()"), 
-                                                    layermanager.endProgress)
-        layermanager.connect(self.attributes, SIGNAL("newPercent(int)"), 
-                                                    layermanager.newPercent)
+        self.attributes.newProgress.connect(layermanager.newProgress)
+        self.attributes.endProgress.connect(layermanager.endProgress)
+        self.attributes.newPercent.connect(layermanager.newPercent)
 
     def toFile(self, fileobj):
         """
@@ -1153,6 +1147,7 @@ class ViewerVectorLayer(ViewerLayer):
         self.sql = None
         self.linewidth = 1
         self.isResultSet = False
+        self.bFill = False
 
     def __del__(self):
         # unfortunately this isn't called when the viewer
@@ -1227,6 +1222,14 @@ class ViewerVectorLayer(ViewerLayer):
         "returns True if there is an attribute filter in place"
         return self.sql is not None
 
+    def setFill(self, bFill):
+        "Sets if the polygons are filled or not"
+        self.bFill = bFill
+
+    def getFill(self):
+        "returns True if polygons are being filled"
+        return self.bFill
+
     def setLineWidth(self, linewidth):
         "sets the line width"
         self.linewidth = linewidth
@@ -1301,8 +1304,8 @@ class ViewerVectorLayer(ViewerLayer):
         (xsize, ysize) = (self.coordmgr.dspWidth, self.coordmgr.dspHeight)
 
         # rasterizeOutlines burns in 1 for outline, 0 otherwise
-        data = vectorrasterizer.rasterizeOutlines(self.ogrLayer, extent, 
-                    xsize, ysize, self.linewidth, self.sql)
+        data = vectorrasterizer.rasterizeLayer(self.ogrLayer, extent, 
+                    xsize, ysize, self.linewidth, self.sql, self.bFill)
 
         # do our lookup
         bgra = self.lut[data]
@@ -1418,8 +1421,8 @@ class ViewerFeatureVectorLayer(ViewerVectorLayer):
         (xsize, ysize) = (self.coordmgr.dspWidth, self.coordmgr.dspHeight)
 
         # rasterizeOutlinesFeature burns in 1 for outline, 0 otherwise
-        data = vectorrasterizer.rasterizeOutlinesFeature(self.ogrFeature, extent, 
-                    xsize, ysize, self.linewidth)
+        data = vectorrasterizer.rasterizeFeature(self.ogrFeature, extent, 
+                    xsize, ysize, self.linewidth, self.bFill)
 
         # do our lookup
         bgra = self.lut[data]
@@ -1444,6 +1447,15 @@ class LayerManager(QObject):
     """
     Class that manages a list of layers
     """
+    # signals
+    # use object rather than ViewerLayer for topLayerChanged
+    # so we can pass None
+    topLayerChanged = pyqtSignal(object, name='topLayerChanged')
+    layersChanged = pyqtSignal(name='layersChanged')
+    newProgressSig = pyqtSignal('QString', name='newProgress')
+    endProgressSig = pyqtSignal(name='endProgress')
+    newPercentSig = pyqtSignal(int, name='newPercent')
+
     def __init__(self):
         QObject.__init__(self)
         self.layers = []
@@ -1477,7 +1489,7 @@ class LayerManager(QObject):
 
         if not newTopLayer is self.topLayer:
             self.topLayer = newTopLayer
-            self.emit(SIGNAL("topLayerChanged(PyQt_PyObject)"), self.topLayer)
+            self.topLayerChanged.emit(self.topLayer)
 
     def getFullExtent(self):
         """
@@ -1559,11 +1571,7 @@ class LayerManager(QObject):
         extent = layer.coordmgr.getWorldExtent()
         self.queryPointLayer.coordmgr.setWorldExtent(extent)
 
-        layer.getImage()
-        self.layers.append(layer)
-        self.recalcFullExtent()
-        self.emit(SIGNAL("layersChanged()"))
-        self.updateTopFilename()
+        self.addLayer(layer)
 
     def addVectorLayer(self, ogrDataSource, ogrLayer, width, height, 
                                 color=DEFAULT_VECTOR_COLOR, resultSet=False,
@@ -1582,12 +1590,7 @@ class LayerManager(QObject):
         layer.open(ogrDataSource, ogrLayer, width, height, extent, color, 
                                 resultSet, origSQL)
 
-        layer.getImage()
-        self.layers.append(layer)
-
-        self.recalcFullExtent()
-        self.emit(SIGNAL("layersChanged()"))
-        self.updateTopFilename()
+        self.addLayer(layer)
 
     def addVectorFeatureLayer(self, ogrDataSource, ogrLayer, ogrFeature, 
                                 width, height, color=DEFAULT_VECTOR_COLOR,
@@ -1605,11 +1608,17 @@ class LayerManager(QObject):
         layer.open(ogrDataSource, ogrLayer, ogrFeature, width, 
                             height, extent, color)
 
+        self.addLayer(layer)
+
+    def addLayer(self, layer):
+        """
+        Add the given layer
+        """
         layer.getImage()
         self.layers.append(layer)
 
         self.recalcFullExtent()
-        self.emit(SIGNAL("layersChanged()"))
+        self.layersChanged.emit()
         self.updateTopFilename()
 
     def removeTopLayer(self):
@@ -1619,7 +1628,7 @@ class LayerManager(QObject):
         if len(self.layers) > 0:
             self.layers.pop()
             self.recalcFullExtent()
-            self.emit(SIGNAL("layersChanged()"))
+            self.layersChanged.emit()
         self.updateTopFilename()
 
     def removeLayer(self, layer):
@@ -1628,7 +1637,7 @@ class LayerManager(QObject):
         """
         self.layers.remove(layer)
         self.recalcFullExtent()
-        self.emit(SIGNAL("layersChanged()"))
+        self.layersChanged.emit()
         self.updateTopFilename()
 
     def moveLayerUp(self, layer):
@@ -1640,7 +1649,7 @@ class LayerManager(QObject):
         if index < len(self.layers) - 1:
             self.layers.pop(index)
             self.layers.insert(index + 1, layer)
-            self.emit(SIGNAL("layersChanged()"))
+            self.layersChanged.emit()
         self.updateTopFilename()
 
     def moveLayerDown(self, layer):
@@ -1652,7 +1661,7 @@ class LayerManager(QObject):
         if index > 0:
             self.layers.pop(index)
             self.layers.insert(index - 1, layer)
-            self.emit(SIGNAL("layersChanged()"))
+            self.layersChanged.emit()
         self.updateTopFilename()
 
     def moveLayerToTop(self, layer):
@@ -1664,7 +1673,7 @@ class LayerManager(QObject):
         if index < len(self.layers) - 1:
             self.layers.pop(index)
             self.layers.append(layer)
-            self.emit(SIGNAL("layersChanged()"))
+            self.layersChanged.emit()
         self.updateTopFilename()
 
     def setDisplayedState(self, layer, state):
@@ -1675,7 +1684,7 @@ class LayerManager(QObject):
         """
         layer.displayed = state
         self.updateTopFilename()
-        self.emit(SIGNAL("layersChanged()"))
+        self.layersChanged.emit()
 
     def timeseriesForward(self):
         """
@@ -1685,7 +1694,7 @@ class LayerManager(QObject):
         for layer in reversed(self.layers):
             if layer.displayed:
                 self.setDisplayedState(layer, False)
-                self.emit(SIGNAL("layersChanged()"))
+                self.layersChanged.emit()
                 break
 
     def timeseriesBackward(self):
@@ -1701,7 +1710,7 @@ class LayerManager(QObject):
             prevLayer = layer
         if prevLayer is not None:
             self.setDisplayedState(prevLayer, True)
-            self.emit(SIGNAL("layersChanged()"))
+            self.layersChanged.emit()
                     
     def getTopLayer(self):
         "Returns the very top layer which may be raster or vector"
@@ -1873,7 +1882,7 @@ class LayerManager(QObject):
             else:
                 raise ValueError('unsupported layer type')
 
-        self.emit(SIGNAL("layersChanged()"))
+        self.layersChanged.emit()
         self.updateTopFilename()
 
 
@@ -1885,19 +1894,19 @@ class LayerManager(QObject):
         """
         Called when we are about to start a new progress
         """
-        self.emit(SIGNAL("newProgress(QString)"), string)
+        self.newProgressSig.emit(string)
 
     def endProgress(self):
         """
         Called when a progress run has finished
         """
-        self.emit(SIGNAL("endProgress()"))
+        self.endProgressSig.emit()
 
     def newPercent(self, percent):
         """
         New progress value
         """
-        self.emit(SIGNAL("newPercent(int)"), percent)
+        self.newPercentSig.emit(percent)
 
 
 def replicateArray(arr, outarr, dspLeftExtra, dspTopExtra, dspRightExtra, 
